==> 0.0.2.tar.gz: lib/pages/splash.dart <==
import 'package:bizdoc/core/app.dart';
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:lottie/lottie.dart';
import 'package:provider/provider.dart';

import 'package:bizdoc/services/base.dart';
import 'package:bizdoc/services/session.dart';
import 'package:bizdoc/core/hub.dart';
import 'home.dart';
import 'server_url.dart';

class SplashPage extends StatefulWidget {
  static var routeName = 'splash';

  const SplashPage({Key? key}) : super(key: key);
  @override
  _SplashPageState createState() => _SplashPageState();
}

class _SplashPageState extends State<SplashPage> {
  InitializationStatus _state = InitializationStatus.ok;
  @override
  Widget build(BuildContext context) {
    return Consumer<AppState>(
      builder: (context, appState, child) => FutureBuilder(
          builder: (context, snapshot) {
            if (snapshot.hasData) {
              switch (_state) {
                case InitializationStatus.unauthorized:
                  {
                    return appState.authentication.authorize(context);
                  }
                case InitializationStatus.ok:
                  {
                    SchedulerBinding.instance!.addPostFrameCallback((_) {
                      Navigator.pushNamed(context, HomePage.routeName);
                    });
                    break;
                  }
                default:
              }
            }
            return Scaffold(
                backgroundColor: Theme.of(context).primaryColor,
                body: Center(
                  child: Column(children: [
                    if (_state == InitializationStatus.exception)
                      Column(children: [
                        IconButton(
                            onPressed: _retry, icon: const Icon(Icons.refresh)),
                        IconButton(
                            alignment: AlignmentDirectional.bottomEnd,
                            onPressed: () => Navigator.pushNamed(
                                context, ServerUrlPage.routeName),
                            icon: const Icon(Icons.settings)),
                      ])
                    else
                      Lottie.asset('assets/logo.json')
                  ]),
                ));
          },
          future: Future.wait([
            Future.delayed(const Duration(microseconds: 1500), () {}),
            _initialize(context, appState)
          ]).whenComplete(() => {})),
    );
  }

  void _retry() {
    setState(() {});
  }

  Future<void> _setup(BuildContext context, AppState appState) async {
    SchedulerBinding.instance!.addPostFrameCallback((_) async {
      final value = await Navigator.pushNamedAndRemoveUntil(
          context, ServerUrlPage.routeName, (_) => false);
    });
  }

  ///
  Future _initialize(BuildContext context, AppState appState) async {
    try {
      await session.refresh();
      if (appState.firebaseSettings != null) {
        hub.initialize(appState.firebaseSettings!);
      }
      _state = InitializationStatus.ok;
    } on UnauthorizedError {
      _state = InitializationStatus.unauthorized;
    } catch (e) {
      _state = InitializationStatus.exception;
    }
  }
}

enum InitializationStatus { ok, unauthorized, exception }

==> 0.0.8.tar.gz: lib/pages/splash.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:lottie/lottie.dart';
import 'package:provider/provider.dart';

import '../services/base.dart';
import '../services/session.dart';
import '../core/app.dart';
import '../core/hub.dart';
import 'home.dart';
import 'server_url.dart';

class SplashPage extends StatefulWidget {
  static var routeName = 'splash';

  const SplashPage({Key? key}) : super(key: key);
  @override
  _SplashPageState createState() => _SplashPageState();
}

class _SplashPageState extends State<SplashPage> {
  InitializationStatus _state = InitializationStatus.ok;
  @override
  Widget build(BuildContext context) {
    return Consumer<AppState>(
      builder: (context, appState, child) => FutureBuilder(
          builder: (context, snapshot) {
            if (snapshot.hasData) {
              switch (_state) {
                case InitializationStatus.unauthorized:
                  {
                    return appState.authentication.authorize(context);
                  }
                case InitializationStatus.ok:
                  {
                    SchedulerBinding.instance!.addPostFrameCallback((_) {
                      Navigator.pushNamed(context, HomePage.routeName);
                    });
                    break;
                  }
                default:
              }
            }
            return Scaffold(
                backgroundColor: Theme.of(context).primaryColor,
                body: Center(
                  child: Column(children: [
                    if (_state == InitializationStatus.exception)
                      Column(children: [
                        IconButton(
                            onPressed: _retry, icon: const Icon(Icons.refresh)),
                        IconButton(
                            alignment: AlignmentDirectional.bottomEnd,
                            onPressed: () => Navigator.pushNamed(
                                context, ServerUrlPage.routeName),
                            icon: const Icon(Icons.settings)),
                      ])
                    else
                      Lottie.asset('assets/logo.json')
                  ]),
                ));
          },
          future: Future.wait([
            Future.delayed(const Duration(microseconds: 1500), () {}),
            _initialize(context, appState)
          ]).whenComplete(() => {})),
    );
  }

  void _retry() {
    setState(() {});
  }

  Future<void> _setup(BuildContext context, AppState appState) async {
    SchedulerBinding.instance!.addPostFrameCallback((_) async {
      final value = await Navigator.pushNamedAndRemoveUntil(
          context, ServerUrlPage.routeName, (_) => false);
    });
  }

  ///
  Future _initialize(BuildContext context, AppState appState) async {
    try {
      await session.refresh();
      if (appState.firebaseSettings != null) {
        hub.initialize(appState.firebaseSettings!);
      }
      _state = InitializationStatus.ok;
    } on UnauthorizedError {
      _state = InitializationStatus.unauthorized;
    } catch (e) {
      _state = InitializationStatus.exception;
    }
  }
}

enum InitializationStatus { ok, unauthorized, exception }
